@@ -13,7 +13,7 @@ MainWindow::MainWindow(QWidget *parent) :
     alternateBoolean = true;
 
     readSettings();
-
+    initMaemoBanner();
     ui->setupUi(this);
     populateListWidget();
     createActionGroups();
@@ -53,6 +53,14 @@ MainWindow::MainWindow(QWidget *parent) :
                                          "PropertyModified",
                                          this, SLOT(focusButtonPressed()));
 
+    QDBusConnection::systemBus().connect(QString(),
+                                         "/org/freedesktop/Hal/devices/computer_logicaldev_input_1",
+                                         "org.freedesktop.Hal.Device",
+                                         "Condition",
+                                         this, SLOT(headSetButtonPressed()));
+
+
+
     if (inizializeAtStartUp)
     {
         qDebug()<<"Inizialize at start up is enabled, starting radio.";
@@ -63,6 +71,11 @@ MainWindow::MainWindow(QWidget *parent) :
     fileSystemWatcher->addPath("/sys/devices/platform/gpio-switch/cam_focus/disable");
     connect(fileSystemWatcher, SIGNAL(fileChanged(QString)), SLOT(setFocusButtonActive()));
 
+    system("amixer -qc0 cset iface=MIXER,name='Jack Bias Switch' on");
+
+
+
+
 }
 
 MainWindow::~MainWindow()
@@ -71,6 +84,7 @@ MainWindow::~MainWindow()
     if (!radio==0) stopRadio();
     delete ui;
 
+    system("amixer -qc0 cset iface=MIXER,name='Jack Bias Switch' off");
 }
 
 void MainWindow::setButtonsIcons()
@@ -92,6 +106,9 @@ void MainWindow::startRadio()
 
     if (headphoneStatus == "disconnected")
     {
+        infoLabel->setText("Please insert headphones before starting Radio");
+        infoBox->show();
+        qDebug()<<"No headphones found, returning.";
         return;
     }
 
@@ -108,6 +125,11 @@ void MainWindow::startRadio()
         radio->start();
     }
 
+    infoLabel->setText("Radio started, bluetooth must not be disabled");
+    infoBox->show();
+
+
+
     metaDataTimer->start(10000);
     setWidgetsEnabled(true);
 }
@@ -120,6 +142,7 @@ void MainWindow::stopRadio()
     delete radio;
     radio=0;
     QProcess::execute("sh /opt/qradio/restoremicrophone.sh");
+
 }
 
 void MainWindow::freqChanged(int)
@@ -234,6 +257,7 @@ void MainWindow::readSettings()
     resumeAfterCall=settings.value("resumeAfterCall", false).toBool();
     inizializeAtStartUp=settings.value("inizializeAtStartUp", false).toBool();
     cameraFocusButtonUsed=settings.value("cameraFocusButtonUsed", true).toBool();
+    headsetButtonBehave = settings.value("headsetButtonBehave", 1).toInt();
 
     QSettings setSettings("qradio", "set" + QString::number(currentSet));
     quickAccessButtonsTextList = setSettings.value("quickAccessButtonsTextList", QStringList()<<"87.6"<< "101.0"<< "99.5"<< "102.3").toStringList();
@@ -569,7 +593,7 @@ void MainWindow::on_actionManual_triggered()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                    tr("<h2>QRadio 0.4.7</h2>"
+                    tr("<h2>QRadio 0.4.4</h2>"
                        "<p>"
                        "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 }
@@ -605,9 +629,9 @@ void MainWindow::on_actionHeadphones_triggered()
 void MainWindow::on_actionSettings_triggered()
 {
     if (radio != 0) saveSettings();
-    SettingsDialog settingsdialog;
-    connect(&settingsdialog, SIGNAL(saveButtonClicked()), SLOT(settingsChanged()));
-    settingsdialog.exec();
+    SettingsDialog* settingsdialog = new SettingsDialog(this);
+    connect(settingsdialog, SIGNAL(saveButtonClicked()), SLOT(settingsChanged()));
+    settingsdialog->show();
 }
 
 void MainWindow::settingsChanged()
@@ -620,6 +644,7 @@ void MainWindow::settingsChanged()
 
 void MainWindow::on_actionAuto_Scan_triggered()
 {
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
     int tempFreq = radio->frequency();
         if (tempFreq<87500000) tempFreq = 87500000;
 
@@ -648,6 +673,7 @@ void MainWindow::on_actionAuto_Scan_triggered()
         }
 
         while (tempFreq<108000000);
+        setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 
 }
 
@@ -757,3 +783,35 @@ void MainWindow::setFocusButtonActive()
     }
     system("echo 'echo 0 > /sys/devices/platform/gpio-switch/cam_focus/disable' | root");
 }
+
+void MainWindow::initMaemoBanner()
+{
+    infoBox = new QMaemo5InformationBox;
+    infoLabel = new QLabel(infoBox);
+    infoLabel->setFixedHeight(50);
+    infoLabel->setAlignment(Qt::AlignCenter);
+    infoBox->setWidget(infoLabel);
+}
+
+void MainWindow::headSetButtonPressed()
+{
+
+    qDebug()<<"Headset button pressed";
+
+    if (radio==0)
+    {
+        return;
+    }
+
+    switch (headsetButtonBehave)
+    {
+    case 1: break;
+    case 2: on_nextStationButton_clicked(); break;
+    case 3: on_actionStop_Radio_triggered(); on_actionStart_Radio_triggered(); break;
+    }
+
+
+
+}
+
+
