@@ -2,6 +2,7 @@
 #define MAINWINDOW_H
 
 #include "emittingbutton.h"
+#include "guidewindow.h"
 #include "settingsdialog.h"
 
 #include <QMainWindow>
@@ -11,6 +12,7 @@
 #include <QFileSystemWatcher>
 #include <QInputDialog>
 #include <QListWidgetItem>
+#include <QMaemo5InformationBox>
 #include <QMessageBox>
 #include <QProcess>
 #include <QRadioTuner>
@@ -41,6 +43,10 @@ private:
 
     QPoint listWidgetPosition;
 
+    //Maemo5 Banner
+    QMaemo5InformationBox *infoBox;
+    QLabel *infoLabel;
+
     //Settings Variables
     QString fontName;
     int freqLabelFontSize;
@@ -57,6 +63,7 @@ private:
     QStringList quickAccessButtonsTextList;
     QStringList stationsList;
     bool cameraFocusButtonUsed;
+    int headsetButtonBehave;
 
     bool alternateBoolean;
 
@@ -73,6 +80,7 @@ private:
     void startRadio();
     void stopRadio();
     void setWidgetsEnabled(bool);
+    void initMaemoBanner();
 
 private slots:
     void freqChanged(int);
@@ -115,6 +123,9 @@ private slots:
 
     void focusButtonPressed();
     void setFocusButtonActive();
+
+    void headSetButtonPressed();
+
 };
 
 #endif // MAINWINDOW_H
